@@ -1,13 +1,13 @@
 #include "Python.h"
-#include "Python-ast.h"
-#include "compile.h"
-#include "node.h"
-#include "grammar.h"
-#include "token.h"
-#include "ast.h"
-#include "parsetok.h"
-#include "errcode.h"
-#include "graminit.h"
+#include "../Include/Python-ast.h"
+#include "../Include/compile.h"
+#include "../Include/node.h"
+#include "../Include/grammar.h"
+#include "../Include/token.h"
+#include "../Include/ast.h"
+#include "../Include/parsetok.h"
+#include "../Include/errcode.h"
+#include "../Include/graminit.h"
 
 extern grammar _Ta27Parser_Grammar; /* from graminit.c */
 
